@@ -25,6 +25,8 @@ get_stop_frequency <- function(gtfs_obj,
                             dow=c(1,1,1,1,1,0,0),
                             by_route=TRUE,
                             wide=FALSE) {
+  gtfs_obj <- set_hms_times(gtfs_obj)
+  
   trips <- gtfs_obj$trips_df 
   stop_times <- gtfs_obj$stop_times_df
   calendar <- gtfs_obj$calendar_df
@@ -52,7 +54,7 @@ get_stop_frequency <- function(gtfs_obj,
                       .data$stop_id,
                       .data$service_id) %>%
       most_frequent_service() %>%
-      dplyr::summarise(departures = n())
+      dplyr::summarise(departures = dplyr::n())
   } 
   else if(by_route==TRUE) {
   stop_time_trips <- stop_time_trips %>%
@@ -61,8 +63,10 @@ get_stop_frequency <- function(gtfs_obj,
                     .data$stop_id,
                     .data$service_id) %>%
     most_frequent_service() %>%
-      dplyr::summarise(departures = n())
+      dplyr::summarise(departures = dplyr::n())
   }
+  # TODO we should only use seconds or hms objects to avoid confusion
+  # TODO is this the right way to calculate the average headway during a timespan? 
   t1 <- end_hour - start_hour
   minutes1 <- 60*t1
   stop_time_trips$headway <- round(minutes1/stop_time_trips$departures,digits=4)
@@ -104,7 +108,7 @@ get_route_frequency <- function(gtfs_obj,
                             quiet = FALSE,
                             service_id = "",
                             dow=c(1,1,1,1,1,0,0)) {
-  if(!quiet) message('Calculating route and stop headways using defaults (6 am to 10 pm for weekday service).')
+  if(!quiet) message('Calculating route and stop headways.')
   gtfs_obj <- get_stop_frequency(gtfs_obj,start_hour,end_hour,service_id,dow)  
   
   if (dim(gtfs_obj$stops_frequency_df)[[1]]!=0) {
@@ -113,7 +117,7 @@ get_route_frequency <- function(gtfs_obj,
       dplyr::summarise(median_headways = as.integer(round(median(.data$headway),0)),
                        mean_headways = as.integer(round(mean(.data$headway),0)),
                        st_dev_headways = round(sd(.data$headway),2),
-                       stop_count = n())
+                       stop_count = dplyr::n())
   } else
   {
     warning("failed to calculate frequency--try passing a service_id from calendar_df")
