@@ -1,7 +1,7 @@
 context('Import metadata from transitfeeds')
 
 working <- function() {
-  url <- "https://developers.google.com/transit/gtfs/examples/sample-feed.zip"
+  url <- "https://github.com/r-transit/tidytransit/raw/master/inst/extdata/sample-feed-fixed.zip"
   connecting <- function(url) {
     r <- base::try(httr::GET(url, httr::timeout(5)))
     if(!assertthat::is.error(r)) r$status_code == 200 else FALSE
@@ -9,11 +9,10 @@ working <- function() {
   connecting(url)
 }
 
-#read_gtfs()
 test_that('the metadata from transitfeeds is a data frame that is not empty', {
   skip_on_cran()
   tfkey <- Sys.getenv('TRANSITFEED_API')
-  if(working()==FALSE){
+  if(!working()){
     skip("no internet, skipping")
   }
   else if (identical(tfkey, "")) {
